@@ -341,6 +341,8 @@ class Database(object):
         # temporary managed context entered ..
         if not self._env:
             # https://lmdb.readthedocs.io/en/release/#lmdb.Environment
+            # https://lmdb.readthedocs.io/en/release/#writemap-mode
+            # map_size: Maximum size database may grow to; used to size the memory mapping.
             # lock=True is needed for concurrent access, even when only by readers (because of space mgmt)
             self._env = lmdb.open(self._dbpath,
                                   map_size=self._maxsize,
@@ -348,7 +350,8 @@ class Database(object):
                                   readonly=self._readonly,
                                   sync=self._sync,
                                   subdir=True,
-                                  lock=self._lock)
+                                  lock=self._lock,
+                                  writemap=True)
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
@@ -385,13 +388,13 @@ class Database(object):
             else:
                 os.remove(dbpath)
 
-    def begin(self, write=False, stats=None):
+    def begin(self, write=False, buffers=False, stats=None):
         assert self._env is not None
 
         if write and self._readonly:
             raise Exception('database is read-only')
 
-        txn = Transaction(db=self, write=write, stats=stats)
+        txn = Transaction(db=self, write=write, buffers=buffers, stats=stats)
         return txn
 
     def sync(self, force=False):
@@ -399,27 +402,47 @@ class Database(object):
 
         self._env.sync(force=force)
 
-    def stats(self):
+    def config(self):
+        res = {
+            'is_temp': self._is_temp,
+            'dbpath': self._dbpath,
+            'maxsize': self._maxsize,
+            'readonly': self._readonly,
+            'lock': self._lock,
+            'sync': self._sync,
+            'create': self._create,
+            'open': self._open,
+        }
+        return res
+
+    def stats(self, include_slots: bool = False):
         assert self._env is not None
 
         current_size = os.path.getsize(os.path.join(self._dbpath, 'data.mdb'))
 
-        res = {
-            'zlmdb_slots': len(self._slots),
-            'current_size': current_size,
-            'max_size': self._maxsize,
-            'free': 1. - float(current_size) / float(self._maxsize),
-            'read_only': self._readonly,
-            'sync_enabled': self._sync,
-        }
-
         # psize 	        Size of a database page in bytes.
         # depth 	        Height of the B-tree.
         # branch_pages 	    Number of internal (non-leaf) pages.
         # leaf_pages 	    Number of leaf pages.
         # overflow_pages 	Number of overflow pages.
         # entries 	        Number of data items.
-        res.update(self._env.stat())
+        stats = self._env.stat()
+        pages = stats['leaf_pages'] + stats['overflow_pages'] + stats['branch_pages']
+        used = stats['psize'] * pages
+
+        self._cache_slots()
+        res = {
+            'num_slots': len(self._slots),
+            'current_size': current_size,
+            'max_size': self._maxsize,
+            'page_size': stats['psize'],
+            'pages': pages,
+            'used': used,
+            'free': 1. - float(used) / float(self._maxsize),
+            'read_only': self._readonly,
+            'sync_enabled': self._sync,
+        }
+        res.update(stats)
 
         # map_addr 	        Address of database map in RAM.
         # map_size 	        Size of database map in RAM.
@@ -430,6 +453,21 @@ class Database(object):
         # num_readers 	    Maximum number of reader slots in simultaneous use since the lock file was initialized.
         res.update(self._env.info())
 
+        if include_slots:
+            slots = self._get_slots()
+            res['slots'] = []
+            with self.begin() as txn:
+                for slot_id in slots:
+                    slot = slots[slot_id]
+                    pmap = _pmap.PersistentMap(slot.slot)
+                    res['slots'].append({
+                        'oid': str(slot_id),
+                        'slot': slot.slot,
+                        'name': slot.name,
+                        'description': slot.description,
+                        'records': pmap.count(txn),
+                    })
+
         return res
 
     def _cache_slots(self):
